#
# spec file for package sdl-ball
#
# Copyright (c) 2021 SUSE LLC
# Copyright Vincent Petry <PVince81@yahoo.fr>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sdl-ball
Version:        1.04
Release:        1.17
Summary:        A Free/OpenSource brick-breaking game with pretty graphics
License:        GPL-3.0-only
Group:          Amusements/Games/Action/Breakout
URL:            http://sdl-ball.sourceforge.net/
# Git-Clone:    https://github.com/DusteDdk/SDL-Ball
Source0:        https://sourceforge.net/projects/sdl-ball/files/sdl-ball/%{version}/SDL-Ball_%{version}_src.tar.xz
Source1:        %{name}.sh
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(SDL_image)
BuildRequires:  pkgconfig(SDL_mixer)
BuildRequires:  pkgconfig(SDL_ttf)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  update-desktop-files

%description
SDL-Ball is a Free/OpenSource brick-breaking game.
It is written in C++ using SDL and OpenGL.

Your mission: To smash your way through a series of progressively harder
and more tricky levels. Your tools: Ultrakinetic titanium balls and your
trusty Gruntmazter-3000-Paddle edition.

Features:
* 50 levels.
* OpenGL eye candy.
* Lots of powerups and powerdowns.
* Powerup Shop - You get special coins for collecting powerups,
  you can spend them on more powerups.
* Highscores.
* Sound.
* Level editor.
* Themes - Selectable from options menu.
  Themes support loading new gfx,snd and levels.
  A theme can be partial, if a file is missing,
  it will be loaded from the default theme.
  You can even mix between gfx,snd and level themes!
* Controllable with Mouse/Keyboard/Joystick and WiiMote.
* Save and Load games
* Cool Introscreen
* Screenshot function

%prep
%setup -q -n SDL-Ball_src

# Convert to unix line end
find . -name "*.cpp" -exec dos2unix "{}" "+"

# Drop unneeded directories
rm -fr win32

%build
export CFLAGS="%{optflags}"
%make_build

%install
# install wrapper
mkdir -p %{buildroot}%{_bindir}
sed 's|@LIBEXECDIR@|%{_libexecdir}|' %{SOURCE1} > %{buildroot}%{_bindir}/%{name}
chmod 755 %{buildroot}%{_bindir}/%{name}

# install executable
install -Dm 0755 %{name} %{buildroot}%{_libexecdir}/%{name}/%{name}

# install data / themes
mkdir -p %{buildroot}%{_libexecdir}/%{name}/themes
for d in default dio-sound-theme ; do
    cp -a themes/$d %{buildroot}%{_libexecdir}/%{name}/themes/
done

# install icon
install -Dm 0644 themes/default/icon32.png %{buildroot}%{_datadir}/pixmaps/%{name}.png

# install .desktop file
%suse_update_desktop_file -i %{name}

# install meta data
install -Dm 0644 %{name}.appdata.xml %{buildroot}%{_datadir}/metainfo/%{name}.appdata.xml


%files
%license LICENSE.txt
%doc README
%dir %{_datadir}/metainfo
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/pixmaps/%{name}.png
%{_libexecdir}/%{name}

%changelog
* Thu Apr 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.04:
  * Improved .desktop file
  * Added metadata for Linux App store
  * Paddle no longer "jumps" to some weird place when menu was used
  * Fixed the bug where the paddle would lock up in one corner
- Fixed wrapper with new libexec directory
* Mon Mar 30 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.03
  * Added a metadata file
  * Minor changes
- Drop sdl-ball-1.02-sdl-ball.desktop.patch. Merged upstream.
- Trim marketing wording from description.
* Mon Oct  3 2016 badshah400@gmail.com
- Do not run fdupes as symlinking icon files vetoes the
  application showing up in appstores despite the presence of its
  appdata file. Since rpmlint does not complain about duplicated
  files, running fdupes is not really needed either.
* Wed Aug 24 2016 mailaender@opensuse.org
- Add support for https://en.opensuse.org/openSUSE:AppStore
* Fri Nov  7 2014 nemysis@gmx.ch
- Update to 1.02, announce message is here:
    http://dustedgames.blogspot.co.uk/2014/10/gosh-sdl-ball-was-updated.html
- Change URL
- Remove Desktop entry file and png, use supplied
- Remove obsolete patches sdl-ball-dontstrip.patch,
  sdl-ball-gcc47.patch and sdl-ball-gcc48.patch, changed by upstream
- Remove obsolete patch sdl-ball-makefile.patch, not accepted by
  upstream
- Remove BuildRequires for Mesa-devel
- Use BuildRequires pkgconfig(SDL_image), pkgconfig(SDL_mixer),
  pkgconfig(SDL_ttf) and pkgconfig(sdl) instead of libSDL-devel,
  libSDL_image-devel, libSDL_mixer-devel and libSDL_ttf-devel
- Add BuildRequires for dos2unix
- Change description
- Add patch sdl-ball-1.02-sdl-ball.desktop.patch
- Use %%{_libexecdir} instead of {_datadir}, because not good Makefile
- Add sdl-ball.sh, that game works from datadir
- Use symlink for %%fdupes
* Sun Feb  9 2014 dap.darkness@gmail.com
- Added sdl-ball-gcc48.patch from Debian Sid
  to build for openSUSE 13.1 & Factory.
* Thu May 24 2012 joop.boonen@opensuse.org
- Created a gcc47 patch and a don't strip for debug patch
- Cleaned spec file up
* Sun Mar 25 2012 jengelh@medozas.de
- Parallel build with %%_smp_mflags; strip redundant spec sections
- Avoid service downloading a new tarball
* Tue Jul 14 2009 PVince81@yahoo.fr
- Changed installation paths
* Fri Jul  3 2009 PVince81@yahoo.fr
- Moved binary from /usr/bin to /usr/games
* Fri Jun 19 2009 PVince81@yahoo.fr
- Fixed libSDL build dependency
* Thu May 21 2009 PVince81@yahoo.fr
- fixed rpm description to be displayed properly in yast
* Sat May  9 2009 PVince81@yahoo.fr
- added missing RPM_OPT_FLAGS
* Wed May  6 2009 PVince81@yahoo.fr
- created package (version 1.01)
